@@ -51,12 +51,12 @@ bool Audio_OUT123::open(AudioConfig &cfg)
 
     try
     {
-        if ((_audiofd = out123_new()) == NULL)
+        if ((_audiofd = out123_new()) == nullptr)
         {
             throw error("Could not init audio driver.");
         }
 
-        if (out123_open(_audiofd, NULL, NULL) == (-1))
+        if (out123_open(_audiofd, nullptr, nullptr) == (-1))
         {
             throw error(out123_strerror(_audiofd));
         }
@@ -77,11 +77,11 @@ bool Audio_OUT123::open(AudioConfig &cfg)
             throw error(out123_strerror(_audiofd));
         }
 
-        cfg.bufSize = 8192; // FIXME make configurable?
+        m_frameSize = 2 * cfg.channels;
 
         try
         {
-            _sampleBuffer = new short[cfg.bufSize];
+            _sampleBuffer = new short[cfg.bufSize * m_frameSize];
         }
         catch (std::bad_alloc const &ba)
         {
@@ -126,7 +126,7 @@ void Audio_OUT123::reset()
     }
 }
 
-bool Audio_OUT123::write(uint_least32_t size)
+bool Audio_OUT123::write(uint_least32_t frames)
 {
     if (_audiofd == nullptr)
     {
@@ -134,7 +134,16 @@ bool Audio_OUT123::write(uint_least32_t size)
         return false;
     }
 
-    out123_play(_audiofd, _sampleBuffer, 2 * size);
-    // FIXME check return value?
+    size_t const bytes = static_cast<size_t>(frames) * m_frameSize;
+    size_t res = out123_play(_audiofd, _sampleBuffer, bytes);
+    if (res < bytes)
+    {
+        int err = out123_errcode(_audiofd);
+        if (err != OUT123_OK)
+        {
+            setError(out123_plain_strerror(err));
+            return false;
+        }
+    }
     return true;
 }
